@@ -15,6 +15,7 @@ import warnings
 from unittest.mock import patch
 
 import pytest
+from platformdirs import __version_info__
 
 from jupyter_core import paths
 from jupyter_core.paths import (
@@ -111,7 +112,8 @@ def test_config_dir():
 @use_platformdirs
 def test_config_dir_darwin():
     config = jupyter_config_dir()
-    assert config == realpath("~/Library/Preferences/Jupyter")
+
+    assert config == realpath("~/Library/Application Support/Jupyter")
 
 
 @windows
@@ -230,6 +232,9 @@ def test_runtime_dir_darwin_legacy():
 @use_platformdirs
 def test_runtime_dir_darwin():
     runtime = jupyter_runtime_dir()
+    if __version_info__[0] < 3:
+        assert runtime == realpath("~/Library/Preferences/Jupyter/runtime")
+        return
     assert runtime == realpath("~/Library/Application Support/Jupyter/runtime")
 
 
@@ -527,7 +532,7 @@ def test_secure_write_win32():
         proc.close()
         for index, line in enumerate(lines):
             if index == 0:
-                line = line.split(filename)[-1].strip().lower()
+                line = line.split(filename)[-1].strip().lower()  # noqa
             match = re.match(r"\s*([^:]+):\(([^\)]*)\)", line)
             if match:
                 usergroup, permissions = match.groups()
@@ -548,7 +553,7 @@ def test_secure_write_win32():
         assert "administrators" in permissions
         assert permissions["administrators"] == {"f"}
         assert "everyone" not in permissions
-        assert len(permissions) == 2  # noqa
+        assert len(permissions) == 2
 
     directory = tempfile.mkdtemp()
     fname = os.path.join(directory, "check_perms")
